@@ -1,7 +1,7 @@
 import io
 import json
 import sys
-from datetime import timedelta
+import uuid
 from distutils.version import StrictVersion
 from unittest import mock
 
@@ -12,28 +12,30 @@ from freezegun import freeze_time
 from django import get_version
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
+from django.core.management.base import CommandError
 from django.db import transaction
 from django.test import override_settings
-from django.utils.timezone import now
+from django.utils.timezone import now, timedelta
 
-from germanium.decorators import data_provider
+from germanium.decorators import data_consumer, data_provider
 from germanium.test_cases.client import ClientTestCase
+from germanium.test_cases.default import GermaniumTestCase
 from germanium.tools import (
     assert_equal, assert_false, assert_http_not_found, assert_http_ok, assert_http_redirect,
     assert_http_too_many_requests, assert_in, assert_is_none, assert_is_not_none, assert_not_in, assert_not_raises,
     assert_raises, assert_true
 )
 
+from security.config import settings
+from security.decorators import atomic_log
 from security.management import call_command
 from security.models import (
     CeleryTaskLog, CeleryTaskLogState, CeleryTaskRunLog, CeleryTaskRunLogState, CommandLog, InputLoggedRequest,
     LoggedRequestStatus, OutputLoggedRequest
 )
-from security.transport import security_requests as requests
-from security.decorators import atomic_log
-from security.utils import log_context_manager
 from security.tasks import get_django_command_task
-from security.management import call_command
+from security.transport import security_requests as requests
+from security.utils import log_context_manager
 
 from apps.test_security.tasks import error_task, retry_task, sum_task, unique_task
 
@@ -48,10 +50,24 @@ class TestException(Exception):
 
 class BaseTestCaseMixin:
 
+    @data_provider
     def create_user(self, username='test', email='test@test.cz'):
         return User.objects._create_user(username, email, 'test', is_staff=True, is_superuser=True)
 
 
+class CeleryHealthCheckCommandTestCaseMixin:
+
+    @data_provider
+    def create_celery_task_log_without_celery_task_run_log(self, task_uuid=uuid.uuid4(), name=None,
+                                                           estimated_time_of_first_arrival=now() + timedelta(days=1),
+                                                           is_set_as_stale=False,
+                                                           queue_name=settings.CELERY_HEALTH_CHECK_DEFAULT_QUEUE,
+                                                           **kwargs):
+        return CeleryTaskLog.objects.create(celery_task_id=task_uuid, name='test_task', is_set_as_stale=is_set_as_stale,
+                                            estimated_time_of_first_arrival=estimated_time_of_first_arrival,
+                                            queue_name=queue_name, **kwargs)
+
+
 def test_call_command(*args, **kwargs):
     call_command(*args, **kwargs, stdout=io.StringIO(), stderr=io.StringIO())
 
@@ -78,7 +94,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         self.get('/')
         assert_equal(InputLoggedRequest.objects.count(), 1)
 
-    @data_provider('create_user')
+    @data_consumer('create_user')
     def test_data_change_should_be_connected_with_logged_request(self, user):
         assert_equal(InputLoggedRequest.objects.count(), 0)
         assert_http_redirect(self.post('/admin/login/', data={'username': 'test', 'password': 'test'}))
@@ -107,7 +123,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
             ContentType.objects.get_for_model(User)
         )
 
-    @data_provider('create_user')
+    @data_consumer('create_user')
     def test_input_logged_request_should_have_right_status(self, user):
         assert_http_ok(self.post('/admin/login/', data={'username': 'invalid', 'password': 'invalid'}))
         assert_equal(InputLoggedRequest.objects.first().status, LoggedRequestStatus.INFO)
@@ -211,7 +227,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(OutputLoggedRequest.objects.count(), 1)
 
     @responses.activate
-    @data_provider('create_user')
+    @data_consumer('create_user')
     def test_output_logged_request_should_be_related_with_object(self, user):
         assert_http_redirect(self.post('/admin/login/', data={'username': 'test', 'password': 'test'}))
         responses.add(responses.GET, 'http://test.cz', body='test')
@@ -233,7 +249,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         input_logged_request = InputLoggedRequest.objects.get()
         assert_in('[Filtered]', input_logged_request.request_body)
 
-    @data_provider('create_user')
+    @data_consumer('create_user')
     def test_sensitive_headers_should_be_hidden(self, user):
         assert_http_redirect(self.post('/admin/login/', data={'username': 'test', 'password': 'test'}))
         input_logged_request = InputLoggedRequest.objects.get()
@@ -244,7 +260,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         input_logged_request = InputLoggedRequest.objects.get()
         assert_equal(input_logged_request.queries['token'], '[Filtered]')
 
-    @data_provider('create_user')
+    @data_consumer('create_user')
     @override_settings(SECURITY_SENSITIVE_DATA_REPLACEMENT='(Filtered)')
     def test_sensitive_replacement_should_be_changed(self, user):
         assert_http_redirect(self.post('/admin/login/', data={'username': 'test', 'password': 'test'}))
@@ -574,7 +590,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(log_context_manager.get_output_request_related_objects(), [])
         assert_is_none(log_context_manager.get_output_request_slug())
 
-    @data_provider('create_user')
+    @data_consumer('create_user')
     def test_task_log_is_processing_should_return_if_task_is_active_or_waiting(self, user):
         assert_false(sum_task.is_processing())
 
@@ -616,3 +632,42 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
 
         celery_task_log.change_and_save(is_set_as_stale=True)
         assert_false(sum_task.is_processing())
+
+
+class CeleryHealthCheckCommandTestCase(CeleryHealthCheckCommandTestCaseMixin, GermaniumTestCase):
+
+    @data_consumer('create_celery_task_log_without_celery_task_run_log')
+    def test_celery_health_check_command_raises_error_if_queue_exceeds_max_tasks_count_limit(self, task_log):
+        max_tasks_count = 0
+
+        with assert_raises(CommandError):
+            call_command('celery_health_check', max_tasks_count=max_tasks_count)
+
+    @data_consumer('create_celery_task_log_without_celery_task_run_log')
+    def test_celery_health_check_command_does_not_raise_error_if_queue_is_within_max_tasks_count_limit(self, task_log):
+        with assert_not_raises(CommandError):
+            call_command('celery_health_check', max_tasks_count=1)
+
+    def test_celery_health_check_command_raises_command_error_for_max_tasks_count_lower_than_zero(self):
+        with assert_raises(CommandError):
+            call_command('celery_health_check', max_tasks_count=-1)
+
+    def test_celery_health_check_command_raises_command_error_for_max_created_at_diff_lower_than_zero(self):
+        with assert_raises(CommandError):
+            call_command('celery_health_check', max_created_at_diff=-1)
+
+    @freeze_time(now())
+    @data_consumer('create_celery_task_log_without_celery_task_run_log')
+    def test_celery_health_check_command_does_not_raise_error_if_queue_is_within_max_created_at_diff_limit(self,
+                                                                                                           task_log):
+        with assert_not_raises(CommandError):
+            call_command('celery_health_check', max_created_at_diff=5)
+
+    @freeze_time(now() - timedelta(days=1))
+    @data_consumer('create_celery_task_log_without_celery_task_run_log')
+    def test_celery_health_check_command_does_raise_error_if_queue_is_not_within_max_created_at_diff_limit(self,
+                                                                                                           task_log):
+        max_created_at_diff = 1
+
+        with assert_raises(CommandError):
+            call_command('celery_health_check', max_created_at_diff=max_created_at_diff)
